@@ -20,7 +20,7 @@
 #' \subsection{Confidence Intervals}{
 #' Confidence intervals are estimated using the Noncentrality parameter method;
 #' These methods searches for a the best \code{ncp} (non-central parameters) for
-#' of the noncentral F distribution for the desired tail-probabilities,
+#' of the noncentral t distribution for the desired tail-probabilities,
 #' and then convert these \code{ncp}s to the corresponding effect sizes.
 #' }
 #'
@@ -188,7 +188,7 @@ glass_delta <- function(x, y = NULL, data = NULL, correction = FALSE, ci = 0.95)
       out[, colnames(out) %in% c(types, "CI_low", "CI_high")] * correction
   }
 
-  class(out) <- c("effectsize_table", class(out))
+  class(out) <- c("effectsize_table","see_effectsize_table", class(out))
   return(out)
 }
 
